@@ -3,7 +3,7 @@
 //! See Universal Serial Bus (USB) HID Usage Tables Version 1.12
 //! <https://www.usb.org/sites/default/files/documents/hut1_12v2.pdf>
 
-use hash32::{Hash, Hasher};
+use core::hash::Hash;
 use num_enum::FromPrimitive;
 use num_enum::IntoPrimitive;
 use packed_struct::prelude::*;
@@ -120,16 +120,6 @@ impl Default for Leds {
     }
 }
 
-impl Hash for Leds {
-    fn hash<H>(&self, state: &mut H)
-    where
-        H: Hasher,
-    {
-        let x: u8 = (*self).into();
-        state.write(&x.to_le_bytes());
-    }
-}
-
 /// Consumer usage page
 ///
 /// See [Universal Serial Bus (USB) HID Usage Tables Version 1.12](<https://www.usb.org/sites/default/files/documents/hut1_12v2.pdf>):
@@ -540,22 +530,22 @@ impl Default for Consumer {
     }
 }
 
-impl Hash for Consumer {
-    fn hash<H>(&self, state: &mut H)
-    where
-        H: Hasher,
-    {
-        let x: u16 = (*self).into();
-        state.write(&x.to_le_bytes());
-    }
-}
-
 /// Generic Desktop usage page
 ///
 /// See [Universal Serial Bus (USB) HID Usage Tables Version 1.12](<https://www.usb.org/sites/default/files/documents/hut1_12v2.pdf>):
 /// Section 4 Desktop Page (0x01)
 #[derive(
-    Debug, Copy, Clone, Eq, PartialEq, Ord, PartialOrd, PrimitiveEnum, IntoPrimitive, FromPrimitive,
+    Debug,
+    Copy,
+    Clone,
+    Eq,
+    PartialEq,
+    Ord,
+    PartialOrd,
+    Hash,
+    PrimitiveEnum,
+    IntoPrimitive,
+    FromPrimitive,
 )]
 #[repr(u8)]
 pub enum Desktop {
@@ -626,22 +616,22 @@ impl Default for Desktop {
     }
 }
 
-impl Hash for Desktop {
-    fn hash<H>(&self, state: &mut H)
-    where
-        H: Hasher,
-    {
-        let x: u8 = (*self).into();
-        state.write(&x.to_le_bytes());
-    }
-}
-
 /// Game Controls usage page
 ///
 /// See [Universal Serial Bus (USB) HID Usage Tables Version 1.12](<https://www.usb.org/sites/default/files/documents/hut1_12v2.pdf>):
 /// Section 4 Game Controls Page (0x05)
 #[derive(
-    Debug, Copy, Clone, Eq, PartialEq, Ord, PartialOrd, PrimitiveEnum, IntoPrimitive, FromPrimitive,
+    Debug,
+    Copy,
+    Clone,
+    Eq,
+    PartialEq,
+    Ord,
+    Hash,
+    PartialOrd,
+    PrimitiveEnum,
+    IntoPrimitive,
+    FromPrimitive,
 )]
 #[repr(u8)]
 pub enum Game {
@@ -685,16 +675,6 @@ impl Default for Game {
     }
 }
 
-impl Hash for Game {
-    fn hash<H>(&self, state: &mut H)
-    where
-        H: Hasher,
-    {
-        let x: u8 = (*self).into();
-        state.write(&x.to_le_bytes());
-    }
-}
-
 /// Keyboard usage page
 ///
 /// See [Universal Serial Bus (USB) HID Usage Tables Version 1.12](<https://www.usb.org/sites/default/files/documents/hut1_12v2.pdf>):
@@ -703,7 +683,17 @@ impl Hash for Game {
 /// Naming from the specification has been preserved where possible but some names
 /// have been shortened or transliterated to be valid rust identifiers
 #[derive(
-    Debug, Copy, Clone, Eq, PartialEq, Ord, PartialOrd, PrimitiveEnum, IntoPrimitive, FromPrimitive,
+    Debug,
+    Copy,
+    Clone,
+    Eq,
+    PartialEq,
+    Ord,
+    PartialOrd,
+    Hash,
+    PrimitiveEnum,
+    IntoPrimitive,
+    FromPrimitive,
 )]
 #[repr(u8)]
 pub enum Keyboard {
@@ -891,22 +881,22 @@ impl Default for Keyboard {
     }
 }
 
-impl Hash for Keyboard {
-    fn hash<H>(&self, state: &mut H)
-    where
-        H: Hasher,
-    {
-        let x: u8 = (*self).into();
-        state.write(&x.to_le_bytes());
-    }
-}
-
 /// Simulation Controls usage page
 ///
 /// See [Universal Serial Bus (USB) HID Usage Tables Version 1.12](<https://www.usb.org/sites/default/files/documents/hut1_12v2.pdf>):
 /// Section 5 Simulation Controls Page (0x02)
 #[derive(
-    Debug, Copy, Clone, Eq, PartialEq, Ord, PartialOrd, PrimitiveEnum, IntoPrimitive, FromPrimitive,
+    Debug,
+    Copy,
+    Clone,
+    Eq,
+    PartialEq,
+    Ord,
+    Hash,
+    PartialOrd,
+    PrimitiveEnum,
+    IntoPrimitive,
+    FromPrimitive,
 )]
 #[repr(u8)]
 pub enum Simulation {
@@ -975,22 +965,22 @@ impl Default for Simulation {
     }
 }
 
-impl Hash for Simulation {
-    fn hash<H>(&self, state: &mut H)
-    where
-        H: Hasher,
-    {
-        let x: u8 = (*self).into();
-        state.write(&x.to_le_bytes());
-    }
-}
-
 /// Telephony Device usage page
 ///
 /// See [Universal Serial Bus (USB) HID Usage Tables Version 1.12](<https://www.usb.org/sites/default/files/documents/hut1_12v2.pdf>):
 /// Section 14 Telephony Device  Page (0x0B)
 #[derive(
-    Debug, Copy, Clone, Eq, PartialEq, Ord, PartialOrd, PrimitiveEnum, IntoPrimitive, FromPrimitive,
+    Debug,
+    Copy,
+    Clone,
+    Eq,
+    PartialEq,
+    Ord,
+    PartialOrd,
+    Hash,
+    PrimitiveEnum,
+    IntoPrimitive,
+    FromPrimitive,
 )]
 #[repr(u8)]
 pub enum Telephony {
@@ -1073,13 +1063,3 @@ impl Default for Telephony {
         Self::Unassigned
     }
 }
-
-impl Hash for Telephony {
-    fn hash<H>(&self, state: &mut H)
-    where
-        H: Hasher,
-    {
-        let x: u8 = (*self).into();
-        state.write(&x.to_le_bytes());
-    }
-}
